univ_Simul: Generating data from a gaussian

Description Usage Arguments Value Examples

Description

Generating data from a gaussian

Usage

1
2
3
4
5
6
7
8
univ_simul(
  ncol_matrix = 30,
  n = 50,
  nclass = 10,
  mean = 68,
  sd = 1.8,
  fr_breaks = c(62, 64, 66, 68, 70, 72, 74, 76, 78)
)

Arguments

ncol_matrix

A number, number of repetitions of the random simulated samples.

n

A number, number of observations in each sample.

nclass

A number, number of classes on the contingency table.

mean

A number, parameter mu value to generate data.

sd

A number, parameter sigma value to generate data.

fr_breaks

A vector, vector containing the values of the referenced as counts.

Value

Returns a list with two objects, the first "simul_data" returns a matrix in which the first column the lower limits of the intervals, in the second column the values of the upper limits of the intervals and the third column the counts of the observations. The second object "med" returns a matrix, in which the first column shows the sampled value and the second column the observation count.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
 library(em.univ)
 library(stats)
 
 simdataaaa <- em.univ::univ_simul(ncol_matrix=1,
                       n=50,
                       nclass = 10,
                       mean = 68,
                       sd = 1.80,
                       fr_breaks=c(62,64,66,68,70,72,74,76,78))
                       
 simdataaaa
 

JoaoPedro2536/univ.em documentation built on Dec. 18, 2021, 1:38 a.m.